# ЗАДАНИЕ ПЕРИОДА ОБНОВЛЕНИЯ ПОКАЗАНИЙ ДАТЧИКОВ:

# Подключаем библиотеку для работы с датчиком температуры и влажности I2C-flash (Sensor Humidity and Temperature).
from pyiArduinoI2Csht import *
from time import sleep

# Объявляем объект sht для работы с функциями и методами библиотеки pyiArduinoI2Csht.
# Если при объявлении объекта указать адрес, например, sht(0x09),
# то пример будет работать с тем модулем, адрес которого был указан.
sht = pyiArduinoI2Csht()

# Указываем модулю обновлять показания датчиков каждые две секунды.
sht.setPeriod(2.0)

while True:
    # Выводим текущую температуру и влажность
    print("t = %.1f" % sht.getTem(),"°C,",
          "RH = %.1f" % sht.getHum(),"%%")
    sleep(.1)



from libcpp.string cimport string

cdef extern from "iarduino_I2C_PI.cpp":
    pass

cdef extern from "iarduino_I2C_SHT.cpp":
    pass

cdef extern from "iarduino_I2C_SHT.h":
    cdef cppclass iarduino_I2C_SHT:
        iarduino_I2C_SHT() except +
        iarduino_I2C_SHT(unsigned char) except +
        bint begin()
        bint changeAddress(unsigned char)
        bint reset()
        unsigned char getAddress()
        unsigned char getVersion()
        float getTem()
        float getHum()
        bint getTemChanged()
        bint getHumChanged()
        bint setTemChange(float)
        bint setHumChange(float)
        bint setPeriod(float)
        bint getPullI2C()
        bint setPullI2C(bint)
        void changeBus(string)



# ПРИМЕР ЧТЕНИЯ ВСЕХ ЗНАЧЕНИЙ ПРИ ИХ ИЗМЕНЕНИИ:

#   Подключаем библиотеку для работы с датчиком температуры и влажности I2C-flash (Sensor Humidity and Temperature).
from pyiArduinoI2Csht import *
from time import sleep

# Объявляем объект sht для работы с функциями и методами библиотеки pyiArduinoI2Csht.
# Если при объявлении объекта указать адрес, например, sht(0xBB), то пример будет
# работать с тем модулем, адрес которого был указан.
sht = pyiArduinoI2Csht()

# Указываем фиксировать изменение температуры окружающей среды более чем на 0.1°С.
sht.setTemChange(0.1)

# Указываем фиксировать изменение влажности воздуха более чем на 1%.
sht.setHumChange(1.0)

while True:

    # Если температура окружающей среды изменилась более чем
    # на значение указанное в функции setTemChange(), то ...
    if sht.getTemChanged():

        # Выводим текущую температуру окружающей среды, от -40 до +125°С.
        print("Температура = %.1f" %
               sht.getTem(),
              "°С.")

    # Если влажность воздуха изменилась более чем на значение указанное в функции setHumChange(), то ...
    if sht.getHumChanged():

        # Выводим текущую влажность воздуха, от 0 до 100%.
        print("Влажность = %.1f" %
               sht.getHum(),
              "%.")
    sleep(0.1)



# distutils: language = c++
# cython: language_level = 3

from iarduino_I2C_SHT cimport iarduino_I2C_SHT
#from time import sleep

DEF_CHIP_ID_FLASH =  0x3C
DEF_CHIP_ID_METRO =  0xC3
DEF_MODEL_SHT   =   0x07

# Адреса регистров модуля:
REG_FLAGS_0          =  0x00
REG_BITS_0           =  0x01
REG_FLAGS_1          =  0x02
REG_BITS_1           =  0x03
REG_MODEL            =  0x04
REG_VERSION          =  0x05
REG_ADDRESS          =  0x06
REG_CHIP_ID          =  0x07
REG_SHT_PERIOD       =  0x08
REG_SHT_FLG          =  0x10
REG_SHT_TEM_L        =  0x11
REG_SHT_HUM_L        =  0x13
REG_SHT_TEM_CHANGE   =  0x15
REG_SHT_HUM_CHANGE   =  0x16
# Позиция битов и флагов:
SHT_TEM_NEGATIVE     =  0x80
SHT_FLG_CHANGED_HUM  =  0x04
SHT_FLG_CHANGED_TEM  =  0x02
SHT_FLG_CHANGED      =  0x01

NO_BEGIN = 1

cdef class pyiArduinoI2Csht:
    cdef iarduino_I2C_SHT c_module

    def __cinit__(self, address=None, auto=None, bus=None):

        if address is not None:

            self.c_module = iarduino_I2C_SHT(address)

            if bus is not None:
                self.changeBus(bus)

            if auto is None:
                #sleep(.5)
                if not self.c_module.begin():

                    print("ошибка инициализации модуля.\n"
                          "Проверьте подключение и адрес модуля,"
                          " возможно не включен интерфейс I2C.\n"
                          " Запустите raspi-config и включите интерфейс"
                          ", инструкция по включению:"
                          " https://wiki.iarduino.ru/page/raspberry-i2c-spi/")

        else:

            self.c_module = iarduino_I2C_SHT()

            if bus is not None:
                self.changeBus(bus)

            if auto is None:
                #sleep(.5)
                if not self.c_module.begin():

                    print("ошибка инициализации модуля.\n"
                          "Проверьте подключение и адрес модуля, "
                          " возможно не включен интерфейс I2C.\n"
                          " Запустите raspi-config и включите интерфейс"
                          ", инструкция по включению:"
                          " https://wiki.iarduino.ru/page/raspberry-i2c-spi/")

    def begin(self):
        return self.c_module.begin()

    def changeAddress(self, unsigned char newAddr):
        return self.c_module.changeAddress(newAddr)

    def reset(self):
        return self.c_module.reset()

    def getAddress(self):
        return self.c_module.getAddress()

    def getVersion(self):
        return self.c_module.getVersion()

    def getTem(self):
        return self.c_module.getTem()

    def getHum(self):
        return self.c_module.getHum()

    def getTemChanged(self):
        return self.c_module.getTemChanged()

    def getHumChanged(self):
        return self.c_module.getHumChanged()

    def setTemChange(self, tem):
        return self.c_module.setTemChange(tem)

    def setHumChange(self, hum):
        return self.c_module.setHumChange(hum)

    def setPeriod(self, tim):
        return self.c_module.setPeriod(tim)

    def getPullI2C(self):
        return self.c_module.getPullI2C()

    def setPullI2C(self, val):
        return self.c_module.setPullI2C(val)

    def changeBus(self, bus):
        return self.c_module.changeBus(bytes(bus, 'utf-8'))
